Learn R Programming

CovSelHigh (version 1.0.0)

cov.sel.high.lasso: cov.sel.high.lasso

Description

Function called by cov.sel.high if type="lasso". Not meant to be used on its own.

Usage

cov.sel.high.lasso(Y, X, minscreen = 2, ...)

Arguments

Y
Outcome variable or treatment variable.
X
A matrix or data frame containing columns of covariates and all functions of covariates e.g. interactions that should be included in the lasso model.
minscreen
The minimum number of columns in X that should be selected.
...
Additional arguments passed on to cv.glmnet.

Value

cov.sel.high.lasso returns a logical vector of the same length as the number of columns in X. The positions of values in the vector refers to the (functions of) covariates in the corresponding X columns. Value TRUE implies that (the function of) the covariate has a corresponding coefficient not equal to zero.

Details

See cv.glmnet.

See Also

cv.glmnet