Function called by cov.sel.high if type="rf". Not meant to be used on its own.
cov.sel.high.rf(Y, X, threshold = 0.25, ntree = 1000, ...)Outcome variable or treatment variable.
A matrix or data frame containing columns of covariates.
Variable importance threshold, see Value.
Number of trees to grow. This should not be set to too small a number, to ensure that every input row gets predicted at least a few times.
Additional arguments passed on to randomForest.
cov.sel.high.rf returns a logical vector of the same length as the number of columns in X. The positions of values in the vector refers to the covariates in the corresponding X columns. Value TRUE implies that the covariate has a variable importance value of more than threshold*the largest observed variable importance value.
See randomForest.