cov.sel.high.lasso(Y, X, minscreen = 2, ...)cv.glmnet.cov.sel.high.lasso returns a logical vector of the same length as the number of columns in X. The positions of values in the vector refers to the (functions of) covariates in the corresponding X columns. Value TRUE implies that (the function of) the covariate has a corresponding coefficient not equal to zero.cv.glmnet.
cv.glmnet