Learn R Programming

CovSelHigh (version 1.0.0)

cov.sel.high.rf: cov.sel.high.rf

Description

Function called by cov.sel.high if type="rf". Not meant to be used on its own.

Usage

cov.sel.high.rf(Y, X, threshold = 0.25, ntree = 1000, ...)

Arguments

Y
Outcome variable or treatment variable.
X
A matrix or data frame containing columns of covariates.
threshold
Variable importance threshold, see Value.
ntree
Number of trees to grow. This should not be set to too small a number, to ensure that every input row gets predicted at least a few times.
...
Additional arguments passed on to randomForest.

Value

cov.sel.high.rf returns a logical vector of the same length as the number of columns in X. The positions of values in the vector refers to the covariates in the corresponding X columns. Value TRUE implies that the covariate has a variable importance value of more than threshold*the largest observed variable importance value.

Details

See randomForest.

See Also

randomForest