cov.sel.high.rf(Y, X, threshold = 0.25, ntree = 1000, ...)randomForest.cov.sel.high.rf returns a logical vector of the same length as the number of columns in X. The positions of values in the vector refers to the covariates in the corresponding X columns. Value TRUE implies that the covariate has a variable importance value of more than threshold*the largest observed variable importance value.
randomForest.
randomForest