Function used to summarize results from cov.sel.high when simulated data is used.
cov.sel.high.sim.res(object)A list returned from cov.sel.high.
cov.sel.high.sim.res returns a list with the following content:
A matrix with the following columns (columns related to average causal effect estimation are only present when betahat=TRUE):
XTuc
Quc
XYuc
Zuc
XTYuc
SinXT
SinQ
SinXY
SinZ
SinXTY
XTeqS
QeqS
XYeqS
ZeqS
XTYeqS
cards
betahatest_psm
betahatse_psm
betahat_cicov_psm
ciL_psm
ciU_psm
betahatest_tmle
betahatse_tmle
betahat_cicov_tmle
ciL_tmle
ciU_tmle
ciwidth_psm
ciwidth_tmle
A list with the following columns (columns related to average causal effect estimation are only present when betahat=TRUE):
Subset_selection
Median_cardinality
Betahat_bias_psm
Betahat_sd_psm
Betahat_mse_psm
Betahat_CI_coverage_psm
Betahat_CI_width_psm
Betahat_mean_lower_CI_psm
Betahat_mean_upper_CI_psm
Betahat_bias_psm
Betahat_sd_psm
Betahat_mse_psm
Betahat_CI_coverage_psm
Betahat_CI_width_psm
Betahat_mean_lower_CI_psm
Betahat_mean_upper_CI_psm
LaTeX table summarizing the results.
LaTeX table summarizing the results.
H<U+00E4>ggstr<U+00F6>m, J. (2017). Data-Driven Confounder Selection via Markov and Bayesian Networks. ArXiv e-prints.